pycocoa.strs.Str

Package pycocoa :: Module strs :: Class Str |
[frames] | no frames]

# Class Str

    object --+
             |
    basestring --+
                 |
               str --+
                     |
        object --+   |
                 |   |
      bases._Type0 --+
                     |
                    Str

Known Subclasses:
  - StrAttd

Python `str` Type, wrapping (immutable) ObjC `NSStr[ing]`.

Instance Methods
copy(self, *ranged) Return a copy of this string. |
Inherited from `str`: `__add__`, `__contains__`, `__eq__`, `__format__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__hash__`, `__le__`, `__len__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__repr__`, `__rmod__`, `__rmul__`, `__sizeof__`, `__str__`, `capitalize`, `center`, `count`, `decode`, `encode`, `endswith`, `expandtabs`, `find`, `format`, `index`, `isalnum`, `isalpha`, `isdigit`, `islower`, `isspace`, `istitle`, `isupper`, `join`, `ljust`, `lower`, `lstrip`, `partition`, `replace`, `rfind`, `rindex`, `rjust`, `rpartition`, `rsplit`, `rstrip`, `split`, `splitlines`, `startswith`, `strip`, `swapcase`, `title`, `translate`, `upper`, `zfill` Inherited from `bases._Type0`: `__init__`, `type2strepr` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, ns_str='') New Str from `str`, Str or `NSStr[ing]`. |

Properties
| NS Get the ObjC instance (`NSString`).
Inherited from `bases._Type0`: `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __new__(cls, ns_str='') Static Method |
New Str from `str`, Str or `NSStr[ing]`. Returns: a new object with type S, a subtype of T Overrides: object.__new__

### copy(self, *ranged) |
Return a copy of this string. Parameters: `ranged` - Optional index range. Returns: The copy (Str).

Property Details

### NS Get the ObjC instance (`NSString`). Get Method: NS(self) - Get the ObjC instance (`NSString`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.